<template>
    <div class="report-overview">
        <div class="group-unit">
            <div class="group-list">
                <div class="list-header">
                    <div style="width: 100%">专项小组</div>
                </div>
                <div :class="['list-item', params.querys[2].value === item.value ? 'active-item' : '']"
                    v-for="(item, index) in groupOptions" :key="index" @click="listItemClick(item)">
                    <div style="width: 100%">{{ item.label }}</div>
                </div>
            </div>
        </div>
        <div class="list-details">
            <div class="list-title">
                <div class="title">
                    资料列表
                </div>
            </div>
            <el-row :gutter="12">
                <el-col :span="5">
                    <div class="search-label">文件名称：</div>
                    <el-input v-model="params.querys[1].value" clearable suffix-icon="el-icon-search"
                        placeholder="请输入文件名称" style="width: 100%"></el-input>
                </el-col>
                <el-col :span="5">
                    <div class="search-label">资料分类：</div>
                    <dict-select :popperClass="`big-search-popper`" class="quarter-selectop" dictCode="zxxzzllx_jc"
                        :hasDefaultOption="true" clearable v-model="params.querys[0].value" style="width: 100%"
                        placeholder="请选择资料分类" />
                </el-col>
                <el-col class="search-btn" :span="2">
                    <div class="search-label"></div>
                    <el-button class="download" type="primary" icon="el-icon-search" @click="getData()">查询</el-button>
                </el-col>
            </el-row>
            <div class="content-box">
                <div class="left-table">
                    <el-table height="calc(100% - 30px)" ref="dataTable" :data="tableData" id="table-bigger-detail"
                        :element-loading-background="loadingColor" v-loading="tableLoading" class="dialog_table" border
                        style="width: 100%" :header-cell-style="{ 'text-align': 'center' }">
                        <el-table-column type="index" label="序号" align="center" width="80">
                        </el-table-column>
                        <el-table-column prop="profileYear" align="center" label="年份" width="140"
                            v-if="params.querys[0].value == 3 || params.querys[0].value == 4">
                        </el-table-column>
                        <el-table-column prop="fileName" label="文件名称" show-overflow-tooltip>
                        </el-table-column>
                        <!-- <el-table-column prop="createTime" align="center" label="上传时间" width="280">
                        </el-table-column> -->
                        <el-table-column align="center" label="操作" width="200">
                            <template v-slot="{ row }">
                                <FileList :fileList="[row]"></FileList>
                            </template>
                        </el-table-column>
                    </el-table>
                    <pagenation class="pagenation" @currentChange="pageChange" :pageResult="params.pageBean">
                    </pagenation>
                </div>
            </div>
        </div>
    </div>
</template>

<script>
import FileList from '@/components/uploadFile/newFileList.vue'
import pagenation from './pagenation.vue'
import apiList from '@/api/bigScreen/majorView.js'
import moment from 'moment'
export default {
    name: 'groupData',
    components: {
        pagenation,
        FileList,
    },
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            loading: false,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            tableLoading: false,
            fileLoading: false,
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'profile_Classify_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'file_Name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'group_code_',
                        relation: 'AND',
                        value: '',
                    }
                ],
            },
            tableData: [],
            currentRow: {},
            fileList: [],
            searchData: {},
            previewUrl: '',
            groupOptions: [
                {
                    id: 100,
                    label: '所有专项小组',
                    value: ''
                },
                {
                    id: 1,
                    label: '党建统领体制改革专项小组',
                    value: 'djtltzggzxxz'
                },
                {
                    id: 2,
                    label: '经济体制改革专项小组',
                    value: 'jjtzggzxxz'
                },
                {
                    id: 3,
                    label: '社会民生领域改革专项小组',
                    value: 'shmslyggzxxz'
                },
                {
                    id: 4,
                    label: '民主与法制领域改革专项小组',
                    value: 'mzyfzlyggzxxz'
                },
                {
                    id: 5,
                    label: '文化体制改革专项小组',
                    value: 'whtzggzxxz'
                },
                {
                    id: 6,
                    label: '平安法治领域改革专项小组',
                    value: 'pafzlyggzxxz'
                },

            ],
            clickTimes: 0,
            groupName: '',
            fileTitle: ''
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        this.getData()
        this.$bus.$on('changeDate', (searchDate) => {
            this.getData()
        })
    },
    created() {
        let { type } = this.$route.query
        this.params.querys[0].value = type
        this.fileTitle = type === '1' ? '总书记要求' : type === '2' ? '中央文件' : type === '3' ? '工作总结' : type === '4' ? '工作要点' : type === '5' ? '外省市改革经验' : '问题'
        this.$emit('searchDateChange')
    },
    methods: {
        listItemClick(item) {
            let _this = this
            _this.clickTimes++;
            if (_this.clickTimes === 2) {
                _this.clickTimes = 0;
                _this.params.querys[2].value = ''
                _this.groupName = ''
                _this.getData()
            }
            setTimeout(function () {
                if (_this.clickTimes === 1) {
                    _this.clickTimes = 0;
                    _this.params.querys[2].value = item.value
                    _this.groupName = item.label
                    _this.getData()
                }
            }, 250)
        },
        getData() {
            this.tableLoading = true
            apiList.getGroupFile(this.params, res => {
                if (res) {
                    this.tableData = res.rows
                }
                this.params.pageBean.total = res.total
                this.tableLoading = false
            })
        },
        pageChange(key) {
            this.params.pageBean.page = key
            this.getData()
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/.el-pagination {
    padding: 0;
    height: 25PX;
}

/deep/.file-item {
    justify-content: center;
    border: none;

    .file_name {
        display: none;
    }

    a {
        .el-link--inner {
            font-size: 18PX !important;
        }
    }

    &:hover {
        background: rgba(2, 115, 233, 0.3);

        .file_name {
            color: #fff;
        }
    }
}

/deep/.classified {
    font-size: 18PX;
}

/deep/.el-tag {
    font-size: 18PX !important;
}

/deep/.el-collapse {
    border: none;
}

/deep/.el-collapse-item__wrap {
    background: transparent;
    border: none;
}

/deep/.el-descriptions .is-bordered .el-descriptions-item__cell {
    border-color: #245cf3;
    background: transparent;
    color: #fff;
    font-size: 18PX;
}

/deep/.el-table td.el-table__cell div {
    background: transparent;
}

/deep/.el-table--enable-row-hover .el-table__body tr:hover>td.el-table__cell {
    background: rgba(2, 115, 233, .5) !important;
}

/deep/.dialog_table.el-table tr:nth-of-type(2n + 1) {
    background: transparent;
}

/deep/.el-descriptions__body {
    background: transparent;
}

/deep/.el-collapse-item__header.is-active {
    border-bottom-color: transparent;
    background: transparent;
    color: #245cf3;
    font-size: 20px;
    font-weight: bold;
}

/deep/.el-collapse-item__header {
    background: transparent;
    color: #245cf3;
    font-size: 18PX !important;
    font-weight: bold;
    border: none;
}

/deep/.el-collapse-item__arrow {
    margin: 0;
    font-weight: bold;
}

/deep/.dialog-table-expand label {
    width: 120px;
    color: #fff;
    font-family: SimHei;
}

/deep/.el-table__body tr.current-row>td.el-table__cell {
    background: rgba(2, 115, 233, .5) !important;
}

/deep/.el-table {
    background: transparent;
    border: 1px solid rgba(2, 115, 233, 0.5);
    // border: none;
    margin-bottom: 10PX;
}

/deep/.el-table th.el-table__cell.is-leaf,
/deep/.el-table td.el-table__cell {
    border-bottom: 1px solid #245cf3 !important;
}

/deep/.el-table--border th {
    border-right: 1px solid #245cf3 !important;

    &:nth-last-child(2) {
        border-right: none !important;
    }
}
/deep/.el-table--border td {
    border-right: 1px solid #245cf3 !important;

    &:last-child {
        border-right: none !important;
    }

    // &:nth-child(5) {
    //     border-right: none !important;
    // }
}

/deep/.el-table--border::after,
/deep/.el-table::before {
    width: 0;
    height: 0;
}

/deep/.el-table tr,
/deep/.el-table thead tr,
/deep/.el-table thead tr th {
    background: transparent !important;
}

/deep/.el-table th.el-table__cell>.cell,
/deep/.el-table td>.cell {
    font-size: 18PX;
    color: #fff;

    >* {
        font-size: 18PX;
    }
}

/deep/.el-input__inner {
    color: #fff;
    font-size: 18PX;
    height: 40PX;
    box-sizing: border-box;
    background: transparent;
    border: 1px solid #114385;

    &::placeholder {
        color: #fff;
        font-size: 18PX !important;
    }

    &::-webkit-input-placeholder {
        font-size: 18PX !important;
    }
}


/deep/.el-table {
    ::-webkit-scrollbar-thumb {
        background-color: #034eb0 !important;
    }

    ::-webkit-scrollbar-track {
        background: #01215a !important;
    }

    ::-webkit-scrollbar {
        width: 18px !important;
        background: #013da4 !important;
    }
}
/deep/.el-table th {
    border: 1px solid #0251ba !important;
    border-right: none !important;

    &:nth-last-child(2) {
        border-right: none !important;
    }
}

/deep/.el-table--border th.el-table__cell.gutter:last-of-type {
    border: none !important;
    border-bottom: 1px solid #0251ba !important;
}
</style>
<style lang="scss" scoped>
* {
    font-family: Microsoft YaHei, Microsoft YaHei;
}

.report-overview {
    display: flex;
    height: 100%;
    margin-top: 5PX;
    gap: 10PX;

    * {
        box-sizing: border-box !important;
    }

    .group-unit {
        height: 100%;
        width: 22%;

        .group-list {
            height: 100%;
            border: 1px solid #245cf3;
            border-radius: 2PX;
        }

        .list-header {
            display: flex;
            width: 100%;
            text-align: center;
            height: 50PX;
            line-height: 50PX;
            background: linear-gradient(180deg, rgba(3, 62, 139, 0) 0%, #033E8B 100%);
            border-image: linear-gradient(90deg, rgba(51.00000075995922, 153.00000607967377, 255, 0), rgba(178.49999696016312, 216.75006687641144, 255, 0.20000000298023224), rgba(51.00000075995922, 153.00000607967377, 255, 0)) 1 1;

            >div {
                font-weight: bold;
                font-size: 18PX;
            }
        }

        .list-item {
            display: flex;
            width: 100%;
            text-align: center;
            height: 50PX;
            line-height: 50PX;

            >div {
                font-size: 18PX;

                &:nth-child(2),
                &:nth-child(3) {
                    font-weight: bold;
                    color: #00D5FF;
                }
            }

            &:nth-child(2n+1) {
                background: #043072;
            }

            &:hover {
                cursor: pointer;
                background: #225092;
            }
        }

        .active-item {
            background: #225092 !important;
        }
    }

    .list-details {
        width: 78%;

        .list-title {
            height: 50PX;
            line-height: 50PX;
            padding: 14PX 0 0 10PX;

            .title {
                position: relative;
                height: 22PX;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                font-size: 18PX;
                color: #3399FF;
                line-height: 22PX;
                text-align: left;

                &::after {
                    content: '';
                    position: absolute;
                    left: -10PX;
                    top: 50%;
                    width: 5px;
                    height: 14px;
                    background: #3399FF;
                    border-radius: 3PX;
                    transform: translateY(-50%);
                }
            }
        }

        >.el-row {
            height: 60PX;
            margin-bottom: 20PX;

            .search-label {
                height: 20PX;
                font-size: 18PX;
                line-height: 20PX;
                margin-bottom: 5px;
            }

            .search-btn {
                /deep/.el-button {
                    height: 40PX;

                    >* {
                        font-size: 18PX;
                    }
                }
            }

            /deep/.el-input__inner {
                color: #fff;
                font-size: 18PX;
                height: 40PX;
                box-sizing: border-box;
                background: transparent;
                border: 1px solid #114385;

                &::placeholder {
                    color: #fff;
                    font-size: 18PX !important;
                }

                &::-webkit-input-placeholder {
                    font-size: 18PX !important;
                }
            }
        }

        .content-box {
            height: calc(100% - 130PX);
            display: flex;
            gap: 10PX;

            .left-table {
                width: 100%;
                height: 100%;
            }

            .right-file {
                width: 100%;
                height: 100%;
                border: 1px solid rgba(2, 115, 233, .5);
                border-radius: 5PX;
                padding: 15PX;
                box-sizing: border-box;

            }
        }

    }
}
</style>
